@@ -1,4 +1,4 @@
 from .utils import *
 from .boxes import *
 from .download import *
-from .zip import *
+from .zip_utils import *
